@@ -23,7 +23,7 @@ RFC_2822 = EMAIL = ('(!a!, ?)d! ?b! ?Y! H:M(:S)?(! !Z|! ?z)?',)
 ISO_8601 = YMD = (invert('Y(!-?m(!-?d(( |%T)H!:?M(!:?S(.f)?)?)?)?)?(! !Z|! ?z)?'),)
 MDY = ('(m!/d!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?',)
 DMY = ('(d!/m!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?',)
-ASN1 = ('b! d(! !H!:!M(!:!S)?)?! Y(! ?!Z|! ?z)?', 'Ymd!H!M!S!Z', '!ymd!H!M!S!Z')
+ASN1 = ('b! d(! !H!:!M(!:!S)?)?! Y(! ?!Z|! ?z)?', 'Y!m!d!H!M!S!Z', '!y!m!d!H!M!S!Z')
 
 DEFAULT_FORMAT = '%Y-%m-%d %H:%M:%S.%f %Z'
 DEFAULT_FORMATS = ISO_8601 + RFC_2822 + ASN1
